@@ -1,7 +1,7 @@
 /**
  * @file test_idxsection.c
  *
- * @copyright Copyright  (C)  2012 Jörg Behrens <behrens@dkrz.de>
+ * @copyright Copyright  (C)  2016 Jörg Behrens <behrens@dkrz.de>
  *                                 Moritz Hanke <hanke@dkrz.de>
  *                                 Thomas Jahns <jahns@dkrz.de>
  *
@@ -14,7 +14,7 @@
  * Maintainer: Jörg Behrens <behrens@dkrz.de>
  *             Moritz Hanke <hanke@dkrz.de>
  *             Thomas Jahns <jahns@dkrz.de>
- * URL: https://redmine.dkrz.de/doc/yaxt/html/index.html
+ * URL: https://doc.redmine.dkrz.de/yaxt/html/
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are  permitted provided that the following conditions are
@@ -43,6 +43,9 @@
  * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
  * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
 
 #include <assert.h>
 #include <limits.h>
@@ -929,58 +932,15 @@ do_tests(Xt_idxlist idxlist, Xt_int * ref_indices, int num_indices,
 
   free(stripes);
 
-  { // test packing and unpacking
-
-    size_t buffer_size = xt_idxlist_get_pack_size(idxlist, MPI_COMM_WORLD);
-
-    // allocate send buffers
-
-    void* send_buffer, * recv_buffer;
-
-    send_buffer = xmalloc(buffer_size);
-    recv_buffer = xmalloc(buffer_size);
-
-    // pack the index vector
-
-    int position = 0;
-    assert(buffer_size <= INT_MAX);
-    xt_idxlist_pack(idxlist, send_buffer, (int)buffer_size, &position,
-                    MPI_COMM_WORLD);
-
-    // send the buffer
-
-    int rank;
-
-    xt_mpi_call(MPI_Comm_rank(MPI_COMM_WORLD, &rank), MPI_COMM_WORLD);
-
-    MPI_Request request;
-
-    xt_mpi_call(MPI_Isend(send_buffer, (int)buffer_size, MPI_PACKED, rank, 0,
-                              MPI_COMM_WORLD, &request), MPI_COMM_WORLD);
-    xt_mpi_call(MPI_Request_free(&request), MPI_COMM_WORLD);
-
-    // receive the buffer
-
-    xt_mpi_call(MPI_Recv(recv_buffer, (int)buffer_size, MPI_PACKED, rank, 0,
-                         MPI_COMM_WORLD, MPI_STATUS_IGNORE), MPI_COMM_WORLD);
-
-    // unpack the buffer
-
-    Xt_idxlist idxlist_copy;
-
-    position = 0;
-    idxlist_copy
-      = xt_idxlist_unpack(recv_buffer, (int)buffer_size, &position,
-                          MPI_COMM_WORLD);
+  {
+    // test packing and unpacking
+    Xt_idxlist idxlist_copy
+      = idxlist_pack_unpack_copy(idxlist);
 
     // check copy
-
     check_idxlist(idxlist_copy, ref_indices, num_indices);
 
     // clean up
-
-    free(send_buffer);
-    free(recv_buffer);
     xt_idxlist_delete(idxlist_copy);
   }
 
@@ -999,3 +959,13 @@ do_tests(Xt_idxlist idxlist, Xt_int * ref_indices, int num_indices,
     xt_idxlist_delete(idxlist_copy);
   }
 }
+
+/*
+ * Local Variables:
+ * c-basic-offset: 2
+ * coding: utf-8
+ * indent-tabs-mode: nil
+ * show-trailing-whitespace: t
+ * require-trailing-newline: t
+ * End:
+ */
